@@ -18,7 +18,7 @@ def export_to_txt(f_name, txt_f_name):
 
 
 # Delete not udp from txt and save to csv with -udp ending
-def delete_non_udp(f_name, header_names):
+def delete_non_udp(f_name, output_filename, header_names):
     """
     Delete non-udp packets from csv and export it to csv file with -udp ending in name
 
@@ -27,8 +27,7 @@ def delete_non_udp(f_name, header_names):
     :param header_names: list
         of column names from file
     """
-    split = f_name.split(".")
     dataset = pd.read_csv(f_name, delimiter='\t', header=None, names=header_names)
     dataset.replace(' ', np.nan, inplace=True)
     dataset = dataset.dropna()
-    dataset.to_csv(split[0] + "-udp." + split[1], sep='\t', index=False)
+    dataset.to_csv(output_filename, sep='\t', index=False)
